@@ -30,7 +30,6 @@ from itertools import takewhile
 import json
 import os
 import unittest
-from unittest import skip
 
 from gi.repository import Click, GLib
 from six import integer_types
@@ -315,7 +314,6 @@ class TestClickSingleDB(TestCase):
             self.db.maybe_remove("a", "1.0")
             self.assertTrue(os.path.exists(version_path))
 
-    @skip("See https://github.com/ubports/click/issues/6")
     def test_maybe_remove_not_running(self):
         with self.run_in_subprocess(
                 "click_find_on_path", "g_spawn_sync",
@@ -335,7 +333,6 @@ class TestClickSingleDB(TestCase):
             self.db.maybe_remove("a", "1.0")
             self.assertFalse(os.path.exists(os.path.join(self.temp_dir, "a")))
 
-    @skip("See https://github.com/ubports/click/issues/6")
     def test_gc(self):
         with self.run_in_subprocess(
                 "click_find_on_path", "g_spawn_sync", "getpwnam"
@@ -408,7 +405,6 @@ class TestClickSingleDB(TestCase):
     # In this case, bug #1479001 expects that the user's registration would
     # be updated to 3, since it was installed after the user registered for
     # 2, which implies that the user would like the update to 3.
-    @skip("See https://github.com/ubports/click/issues/6")
     def test_gc_fixes_old_user_registrations(self):
         with self.run_in_subprocess("getpwnam") as (enter, preloads):
             enter()
@@ -477,12 +473,13 @@ class TestClickSingleDB(TestCase):
 
     def _set_stat_side_effect(self, preloads, side_effect, limit):
         limit = limit.encode()
-        preloads["__xstat"].side_effect = (
-            lambda ver, path, buf: side_effect(
-                "__xstat", limit, ver, path, buf))
-        preloads["__xstat64"].side_effect = (
-            lambda ver, path, buf: side_effect(
-                "__xstat64", limit, ver, path, buf))
+        for func_name in self.STAT_FUNCTIONS:
+            if func_name.startswith("__x"): # __xstat{,64}
+                preloads[func_name].side_effect = (
+                    partial(side_effect, func_name, limit))
+            else: # stat{,64}, __stat64_time64
+                preloads[func_name].side_effect = (
+                    partial(side_effect, func_name, limit, 3))
 
     def test_ensure_ownership_quick_if_correct(self):
         def stat_side_effect(name, limit, ver, path, buf):
@@ -496,7 +493,7 @@ class TestClickSingleDB(TestCase):
                 return -1
 
         with self.run_in_subprocess(
-                "chown", "getpwnam", "__xstat", "__xstat64",
+                "chown", "getpwnam", *self.STAT_FUNCTIONS
                 ) as (enter, preloads):
             enter()
             preloads["getpwnam"].side_effect = (
@@ -520,7 +517,7 @@ class TestClickSingleDB(TestCase):
                 return -1
 
         with self.run_in_subprocess(
-                "chown", "getpwnam", "__xstat", "__xstat64",
+                "chown", "getpwnam", *self.STAT_FUNCTIONS
                 ) as (enter, preloads):
             enter()
             preloads["getpwnam"].side_effect = (
@@ -569,7 +566,7 @@ class TestClickSingleDB(TestCase):
                 return -1
 
         with self.run_in_subprocess(
-                "chown", "getpwnam", "__xstat", "__xstat64",
+                "chown", "getpwnam", *self.STAT_FUNCTIONS
                 ) as (enter, preloads):
             enter()
             preloads["chown"].return_value = -1
