@@ -35,7 +35,7 @@ import stat
 import subprocess
 import tarfile
 
-from unittest import skip, skipUnless
+from unittest import skipUnless
 
 from debian.deb822 import Deb822
 from gi.repository import Click
@@ -75,7 +75,6 @@ def mock_quiet_subprocess_call():
         yield mock_call
 
 
-@skip('Tests failing on 20.04 due to preload hack not working.')
 class TestClickInstaller(TestCase):
     def setUp(self):
         super(TestClickInstaller, self).setUp()
