@@ -28,7 +28,6 @@ import os
 import shutil
 import tempfile
 from textwrap import dedent
-from unittest import skip
 
 # Important:
 #
@@ -57,7 +56,6 @@ from click_package.tests.helpers import (
 )
 
 
-@skip('Tests failing on 20.04 due to preload hack not working.')
 class TestClickUser(TestCase):
     def setUp(self):
         super(TestClickUser, self).setUp()
@@ -576,7 +574,6 @@ class TestClickUser(TestCase):
         self.assertTrue(registry.is_removable("b"))
 
 
-@skip('Tests failing on 20.04 due to preload hack not working.')
 class StopAppTestCase(TestCase):
 
     def setUp(self):
@@ -609,7 +606,6 @@ class StopAppTestCase(TestCase):
             self.assertEqual("meep_a-app_2.0", f.read().strip())
 
 
-@skip('Tests failing on 20.04 due to preload hack not working.')
 class UserDataRemovalTestCase(TestCase):
 
     @classmethod
