@@ -21,6 +21,12 @@
 
 #define _GNU_SOURCE
 
+/* ensure we see *64 variants and they aren't transparently used */
+#undef _TIME_BITS
+#undef _FILE_OFFSET_BITS
+#define _FILE_OFFSET_BITS 32
+#define _LARGEFILE64_SOURCE
+
 #include <assert.h>
 #include <dlfcn.h>
 #include <fcntl.h>
@@ -49,14 +55,27 @@ static int (*libc_lchown) (const char *, uid_t, gid_t) = (void *) 0;
 static int (*libc_link) (const char *, const char *) = (void *) 0;
 static int (*libc_mkdir) (const char *, mode_t) = (void *) 0;
 static int (*libc_mkfifo) (const char *, mode_t) = (void *) 0;
-static int (*libc_open) (const char *, int, mode_t) = (void *) 0;
+static int (*libc_open) (const char *, int, ...) = (void *) 0;
 #ifdef __GLIBC__
-static int (*libc_open64) (const char *, int, mode_t) = (void *) 0;
+static int (*libc_open64) (const char *, int, ...) = (void *) 0;
 #endif
 static int (*libc_symlink) (const char *, const char *) = (void *) 0;
 static int (*libc___xmknod) (int, const char *, mode_t, dev_t *) = (void *) 0;
 static int (*libc___xstat) (int, const char *, struct stat *) = (void *) 0;
 static int (*libc___xstat64) (int, const char *, struct stat64 *) = (void *) 0;
+static int (*libc_stat) (const char *, struct stat *) = (void *) 0;
+#ifdef __GLIBC__
+static int (*libc_stat64) (const char *, struct stat64 *) = (void *) 0;
+
+/*
+ * Note: The actual argument of __stat64_time64() is actually struct stat64
+ * defined to use time64_t. The type is never exposed externally unless
+ * stat{,64}() is going to redirect to that variant. But since we aren't going
+ * to dereference it, a forward declaration is fine.
+ */
+struct stat64_t64;
+static int (*libc___stat64_time64) (const char *, struct stat64_t64 *) = (void *) 0;
+#endif
 
 uid_t euid;
 struct passwd root_pwd;
@@ -109,10 +128,18 @@ static void __attribute__ ((constructor)) clickpreload_init (void)
     GET_NEXT_SYMBOL (__xmknod);
     GET_NEXT_SYMBOL (__xstat);
     GET_NEXT_SYMBOL (__xstat64);
+    GET_NEXT_SYMBOL (stat);
+#ifdef __GLIBC__
+    GET_NEXT_SYMBOL (stat64);
+#if __TIMESIZE == 32
+    GET_NEXT_SYMBOL (__stat64_time64);
+#endif
+#endif
 
     euid = geteuid ();
     /* dpkg only cares about these fields. */
     root_pwd.pw_uid = 0;
+    root_pwd.pw_name = "root";
     root_grp.gr_gid = 0;
 
     base_path = getenv ("CLICK_BASE_DIR");
@@ -434,6 +461,46 @@ int __xstat64 (int ver, const char *pathname, struct stat64 *buf)
     return (*libc___xstat64) (ver, pathname, buf);
 }
 
+int stat(const char * pathname, struct stat * buf)
+{
+    if (!libc_stat)
+        clickpreload_init ();  /* also needed for package_path */
+
+    if (package_path && strcmp (pathname, package_path) == 0)
+        return fstat (package_fd, buf);
+
+    return (*libc_stat) (pathname, buf);
+}
+
+#ifdef __GLIBC__
+int stat64(const char * pathname, struct stat64 * buf)
+{
+    if (!libc_stat64)
+        clickpreload_init ();  /* also needed for package_path */
+
+    if (package_path && strcmp (pathname, package_path) == 0)
+        return fstat64 (package_fd, buf);
+
+    return (*libc_stat64) (pathname, buf);
+}
+
+#if __TIMESIZE == 32
+
+extern int __fstat64_time64(int fd, struct stat64_t64 * buf);
+
+int __stat64_time64(const char * pathname, struct stat64_t64 * buf)
+{
+    if (!libc___stat64_time64)
+        clickpreload_init ();  /* also needed for package_path */
+
+    if (package_path && strcmp (pathname, package_path) == 0)
+        return __fstat64_time64 (package_fd, buf);
+
+    return (*libc___stat64_time64) (pathname, buf);
+}
+#endif // __TIMESIZE == 32
+#endif // __GLIBC__
+
 /* As well as write sandboxing, our versions of chmod and fchmod also
  * prevent the 0200 (u+w) permission bit from being removed from unpacked
  * files.  dpkg normally expects to be run as root which can override DAC
